https://svn.lrde.epita.fr/svn/oln/trunk/olena
Index: ChangeLog
from Roland Levillain <roland(a)lrde.epita.fr>
Move oln::color to oln::value::color.
* oln/color/rgb.hh: Move...
* oln/value/color/rgb.hh: ...here.
(oln::color): Move the contents of this namespace...
(oln::value::color): ...into this one.
* oln/value/all.hh: Adjust.
* oln/Makefile.am (nobase_oln_HEADERS):
s|color/rgb.hh|value/color/rgb.hh|.
Makefile.am | 4 ++--
value/all.hh | 2 +-
value/color/rgb.hh | 14 ++++++++++----
3 files changed, 13 insertions(+), 7 deletions(-)
Index: oln/value/all.hh
--- oln/value/all.hh (revision 671)
+++ oln/value/all.hh (working copy)
@@ -35,7 +35,7 @@
# include <oln/value/bin.hh>
# include <oln/value/default.hh>
-# include <oln/color/rgb.hh>
+# include <oln/value/color/rgb.hh>
#endif // ! OLN_VALUE_ALL_HH
Index: oln/Makefile.am
--- oln/Makefile.am (revision 671)
+++ oln/Makefile.am (working copy)
@@ -3,8 +3,6 @@
olndir = $(includedir)/oln
nobase_oln_HEADERS = \
\
- color/rgb.hh \
- \
core/1d/aliases.hh \
core/1d/array1d.hh \
core/1d/dpoint1d.hh \
@@ -180,6 +178,8 @@
morpher/thru_mfun.hh \
morpher/value_cast.hh \
\
+ value/color/rgb.hh \
+ \
value/accessor.hh \
value/all.hh \
value/default.hh \
Index: oln/value/color/rgb.hh
--- oln/value/color/rgb.hh (revision 671)
+++ oln/value/color/rgb.hh (working copy)
@@ -25,8 +25,8 @@
// reasons why the executable file might be covered by the GNU General
// Public License.
-#ifndef OLN_CORE_COLOR_RGB_HH
-# define OLN_CORE_COLOR_RGB_HH
+#ifndef OLN_CORE_VALUE_COLOR_RGB_HH
+# define OLN_CORE_VALUE_COLOR_RGB_HH
# include <xtd/vec.hh>
# include <oln/core/abstract/value.hh>
@@ -35,6 +35,10 @@
namespace oln
{
+ namespace value
+ {
+
+ // FIXME: Perhaps this additional namespace is not necessary.
namespace color
{
@@ -177,9 +181,11 @@
# endif
- } // end of namespace oln::color
+ } // end of namespace oln::value::color
+
+ } // end of namespace oln::value
} // end of namespace oln
-#endif // ! OLN_CORE_COLOR_RGB_HH
+#endif // ! OLN_CORE_VALUE_COLOR_RGB_HH